/*

Copyright (C) 2009 Jaroslav Barton <djaara@djaara.net>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/

#ifndef FMDBUSCONN_H_
#define FMDBUSCONN_H_

#include <QObject>

#include "FingerManagerDevicesModel.h"

#define INTERFACE_ACQUIRE_RETRY 3

class QDBusInterface;

class FMDbusConn : public QObject {
	Q_OBJECT

	public:
		static FMDbusConn*	getConn();
		void 				releaseConn();
		FingerManagerDevicesModel*	getDevices();
		QStringList			getFingers(const QString &devicePath, const QString &username);
		bool				deleteAllEnrolledFingers(const QString &device, const QString &username);
		void				claimDevice(const QString &devicePath, const QString &username);
		void				releaseDevice();
		int				    getEnrollStages();
		bool				isDeviceClaimed();
		void				enrollStart(const QString &fingerName);
		QString				getScanType();
	
	signals:
		void EnrollStatus(QString status, bool result);

	private slots:
		void enrollStatusSlot(QString status, bool result);

	private:
		FMDbusConn();
		~FMDbusConn();
		QDBusInterface*	    getManagerIface(int retry = INTERFACE_ACQUIRE_RETRY);
		QDBusInterface*     getDeviceInterface(const QString &devicePath);
		QString			    getDeviceName(const QString &devicePath);
		void			    enrollStop();
		QDBusInterface	    *m_managerIface;
		QDBusInterface	    *m_claimedDevice;
		bool				m_isEnrollStopped;
		bool				m_releaseInProgress;
};

#endif /*FMDBUSCONN_H_*/
